Module types

Module types 

Structs

SyntheticNameBuilder
Generates stable synthetic names for anonymous functions and classes.

Functions

has_synthetic_anonymous_segment
True when any ::-separated segment of qualified_name is a synthetic anonymous name, per is_synthetic_anonymous_segment.
is_synthetic_anonymous_segment
True when segment is a synthetic name minted for an unnamed construct.